@@ -44,7 +44,7 @@ class MailjetService(EmailServiceBase):
             file_name = os.path.basename(file_path_name)
 
             attached_file_item = {
-                "Content-type": "text/plain",  # @todo: Implement binary file support
+                "ContentType": "text/plain",  # @todo: Implement binary file support
                 "Filename": file_name,
                 "content": file_base64_content.decode(),
             }
@@ -101,7 +101,7 @@ class MailjetService(EmailServiceBase):
             'TextPart': email.text_content,
             'HTMLPart': email.html_content,
             'CustomID': uuid.uuid4().hex,
-            'Attachments': email.attached_files and cls.__build_attached_file_item(email.attached_files),
+            'Attachments': email.attached_files and cls.__build_attached_file_items(email.attached_files),
         }
 
         return message
